@@ -1,7 +1,7 @@
 import os
 
 def install():
-    os.system('pip install --index-url https://test.pypi.org/simple/ --extra-index-url https://pypi.org/simple --no-deps instabase-apps-sdk-mohit-instabase==0.0.7')
+    os.system('pip install instabase==0.0.1')
 
 install()
 
